const initialState = {
    statementConfig: [],
    loadingStatementConfig: false,
    configStatemen: false,
    actionTransfer: false,
    actionInputCashbox: false,
    actionOutputCashbox: false,
    actionStatementConfirm: false,
    actionModifyStatement: true
}

const state = {
    statementConfig: initialState.statementConfig,
    loadingStatementConfig: initialState.loadingStatementConfig,
    configStatemen: initialState.configStatemen,
    actionTransfer: initialState.actionTransfer,
    actionInputCashbox: initialState.actionInputCashbox,
    actionOutputCashbox: initialState.actionOutputCashbox,
    actionStatementConfirm: initialState.actionStatementConfirm,
    actionModifyStatement: initialState.actionModifyStatement,
}

const getters = {
    statementConfig(state) {
        return state.statementConfig
    },
    loadingStatementConfig(state) {
        return state.loadingStatementConfig
    },
    actionTransfer(state) {
        return state.actionTransfer
    },
    actionInputCashbox(state) {
        return state.actionInputCashbox
    },
    actionOutputCashbox(state) {
        return state.actionOutputCashbox
    },
    actionStatementConfirm(state) {
        return state.actionStatementConfirm
    },
    configStatemen(state) {
        return state.configStatemen;
    },
    actionModifyStatement(state) {
        return  state.actionModifyStatement
    },
}

const mutations = {
    setStatementConfig(state, payload) {
        state.statementConfig = payload
    },
    setLoadingStatementConfig(state, payload) {
        state.loadingStatementConfig = !!payload
    },
    setConfigStatemen(state, payload) {
        if (!!payload.length) {
            state.configStatemen = payload[0]
        }
    },
    /* Allowed Actions statement */
    setAllowedActions(state, payload) {

        let config = !payload ? null :state.configStatemen
        if (!config){
            state.actionTransfer = false
            state.actionInputCashbox = false
            state.actionOutputCashbox = false
            state.actionStatementConfirm = false
            // !! mas acciones agregar aqui
            return
        }

        //  @Transfer
        let resultTransfer = !!config.transfer.userIds.find(item => item === payload.userSession) && !!config.transfer.statementIds.find(item => item === payload.typeStatement.id)
        state.actionTransfer = resultTransfer

        // @Input
        let resultInput = !!config.inputCashBox.userIds.find(item => item === payload.userSession) && !!config.inputCashBox.statementIds.find(item => item === payload.typeStatement.id)
        state.actionInputCashbox = resultInput

        // @Output
        let resultOutput = !!config.outputCashBox.userIds.find(item => item === payload.userSession) && !!config.outputCashBox.statementIds.find(item => item === payload.typeStatement.id)
        state.actionOutputCashbox = resultOutput

        // @Confirm
        let resultConfirm = !!config.statementConfirm.userIds.find(item => item === payload.userSession)
        state.actionStatementConfirm = resultConfirm
    },
}

const actions = {
    initStatementConfig({ commit }, payload) {
        commit('setStatementConfig',payload)
        commit('setConfigStatemen', payload)
        commit('setLoadingStatementConfig', payload)
    },
    verifyActionCashbox({ getters, commit }, payload) {
        commit('setAllowedActions', payload)
    },
    resetStatementConfig({commit}){
        commit('setStatementConfig',[])
        commit('setLoadingStatementConfig', false)
        commit('setConfigStatemen', [])
        commit('setAllowedActions', null)
    },
}

export default {
    state,
    getters,
    mutations,
    actions
}
